# Generated by Django 2.1.7 on 2019-03-07 11:03

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [("nuntius", "0009_verbose_names")]

    operations = [
        migrations.AlterModelOptions(
            name="campaign",
            options={"verbose_name": "Campaign", "verbose_name_plural": "Campaigns"},
        ),
        migrations.AlterModelOptions(
            name="campaignsentevent",
            options={
                "verbose_name": "Sent event",
                "verbose_name_plural": "Sent events",
            },
        ),
        migrations.AlterField(
            model_name="campaignsentevent",
            name="campaign",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="nuntius.Campaign",
                verbose_name="Campaign",
            ),
        ),
        migrations.AlterField(
            model_name="campaignsentevent",
            name="datetime",
            field=models.DateTimeField(auto_now_add=True, verbose_name="Sending time"),
        ),
        migrations.AlterField(
            model_name="campaignsentevent",
            name="email",
            field=models.EmailField(
                max_length=254, verbose_name="Email address at sending time"
            ),
        ),
    ]
