# Generated by Django 2.1.7 on 2019-03-06 10:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("nuntius", "0007_message_content_text_blank")]

    operations = [
        migrations.AddField(
            model_name="campaign",
            name="first_sent",
            field=models.DateTimeField(blank=True, null=True),
        )
    ]
