# Generated by Django 2.1.7 on 2019-03-07 11:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("nuntius", "0010_verbose_names")]

    operations = [
        migrations.AddField(
            model_name="campaignsentevent",
            name="click_count",
            field=models.IntegerField(
                default=0, editable=False, verbose_name="Click count"
            ),
        ),
        migrations.AddField(
            model_name="campaignsentevent",
            name="open_count",
            field=models.IntegerField(
                default=0, editable=False, verbose_name="Open count"
            ),
        ),
    ]
